@@ -1,7 +1,7 @@
 package Tcl;
 use Carp;
 
-$Tcl::VERSION = '0.87';
+$Tcl::VERSION = '0.88';
 $Tcl::STACK_TRACE = 1;
 
 =head1 NAME
@@ -66,20 +66,22 @@ returned (the object argument omitted in each case).
 
 Invoke I<Tcl_Init> on the interpeter.
 
-=item Eval (STRING)
+=item Eval (STRING, FLAGS)
 
 Evaluate script STRING in the interpreter. If the script returns
-successfully (TCL_OK) then the Perl return value corresponds to
-interp->result otherwise a I<die> exception is raised with the $@
-variable corresponding to interp->result. In each case, I<corresponds>
-means that if the method is called in scalar context then the string
-interp->result is returned but if the method is called in list context
-then interp->result is split as a Tcl list and returned as a Perl list.
+successfully (TCL_OK) then the Perl return value corresponds to Tcl
+interpreter's result otherwise a I<die> exception is raised with the $@
+variable corresponding to Tcl's interpreter result object. In each case,
+I<corresponds> means that if the method is called in scalar context then
+the string result is returned but if the method is called in list context
+then the result is split as a Tcl list and returned as a Perl list.
+The FLAGS field is optional and can be a bitwise OR of the constants
+Tcl::EVAL_GLOBAL or Tcl::EVAL_DIRECT.
 
 =item GlobalEval (STRING)
 
-Evalulate script STRING at global level. Otherwise, the same as
-I<Eval>() above.
+REMOVED.  Evalulate script STRING at global level.
+Call I<Eval>(STRING, Tcl::EVAL_GLOBAL) instead.
 
 =item EvalFile (FILENAME)
 
@@ -115,11 +117,11 @@ code as:
   my $r = 'aaaa';
   button(".d", -textvariable => \$r, -command=>sub {$r++});
 
-3.  As a special case, it is supported a mechanism to deal with Tk's
-special event variables (they are mentioned as '%x', '%y' and so on
-throughout Tcl).  When creating a subrutine reference that uses such
-variables, you must declare the desired variables using Tcl::Ev as
-the first argument to the subroutine.  Example:
+3.  As a special case, there is a mechanism to deal with Tk's special event
+variables (they are mentioned as '%x', '%y' and so on throughout Tcl).
+When creating a subroutine reference that uses such variables, you must
+declare the desired variables using Tcl::Ev as the first argument to the
+subroutine.  Example:
 
   sub textPaste {
       my ($x,$y,$w) = @_;
@@ -177,7 +179,7 @@ for details.
 
 =item result ()
 
-Returns the current interp->result field. List v. scalar context is
+Returns the current Tcl interpreter result. List v. scalar context is
 handled as in I<Eval>() above.
 
 =item CreateCommand (CMDNAME, CMDPROC, CLIENTDATA, DELETEPROC)
@@ -217,32 +219,33 @@ registered commands.
 
 =item SetResult (STRING)
 
-Sets interp->result to STRING.
+Sets Tcl interpreter result to STRING.
 
 =item AppendResult (LIST)
 
-Appends each element of LIST to interp->result.
+Appends each element of LIST to Tcl's interpreter result object.
 
 =item AppendElement (STRING)
 
-Appends STRING to interp->result as an extra Tcl list element.
+Appends STRING to Tcl interpreter result object as an extra Tcl list element.
 
 =item ResetResult ()
 
-Resets interp->result.
+Resets Tcl interpreter result.
 
 =item SplitList (STRING)
 
 Splits STRING as a Tcl list. Returns a Perl list or the empty list if
 there was an error (i.e. STRING was not a properly formed Tcl list).
-In the latter case, the error message is left in interp->result.
+In the latter case, the error message is left in Tcl's interpreter
+result object.
 
 =item SetVar (VARNAME, VALUE, FLAGS)
 
 The FLAGS field is optional. Sets Tcl variable VARNAME in the
 interpreter to VALUE. The FLAGS argument is the usual Tcl one and
-can be a bitwise OR of the constants $Tcl::GLOBAL_ONLY,
-$Tcl::LEAVE_ERR_MSG, $Tcl::APPEND_VALUE, $Tcl::LIST_ELEMENT.
+can be a bitwise OR of the constants Tcl::GLOBAL_ONLY,
+Tcl::LEAVE_ERR_MSG, Tcl::APPEND_VALUE, Tcl::LIST_ELEMENT.
 
 =item SetVar2 (VARNAME1, VARNAME2, VALUE, FLAGS)
 
@@ -297,16 +300,92 @@ Omit the I<$flags> argument if not wanted. Any alteration to Perl
 variable I<$hash{"key"}> affects the Tcl variable I<array(key)>
 and I<vice versa>.
 
+=head2 Accessing Perl from within Tcl
+
+After creation of Tcl interpreter, in addition to evaluation of Tcl/Tk
+commands within Perl, other way round also instantiated. Within a special
+namespace C< ::perl > following objects are created:
+
+   ::perl::Eval
+
+So it is possible to use Perl objects from within Tcl.
+
+=head2 Moving Tcl/Tk around with Tcl.pm
+
+NOTE: explanations below is for developers managing Tcl/Tk installations
+itself, users should skip this section.
+
+In order to create Tcl/Tk application with this module, you need to make
+sure that Tcl/Tk is available within visibility of this module. There are
+many ways to achieve this, varying on ease of starting things up and
+providing flexible moveable archived files.
+
+Following list enumerates them, in order of increased possibility to change
+location.
+
+=over
+
+=item * First method
+
+Install Tcl/Tk first, then install Perl module Tcl, so installed Tcl/Tk will
+be used. This is most normal approach, and no care of Tcl/Tk distribution is
+taken on Perl side (this is done on Tcl/Tk side)
+
+=item * Second method
+
+Copy installed Tcl/Tk binaries to some location, then install Perl module Tcl
+with a special action to make Tcl.pm know of this location. This approach
+makes sure that only chosen Tcl installation is used.
+
+=item * Third method
+
+During compiling Tcl Perl module, Tcl/Tk could be statically linked into
+module's shared library and all other files zipped into a single archive, so
+each file extracted when needed.
+
+=back
+
+Some global variables within $Tcl::config:: namespace are used to make
+such installations possible.
+
+=head3 First method
+
+=head3 Second method
+
+To use second approach, desired set of Tcl/Tk binaries should be prepared
+in a single directory. Mostly these files could be files from existing Tcl/Tk
+installation.
+
+Use C<create-moveable-dist.pl> script to create proper configuration this way.
+
+From inmplementation side of view, following things are done in this way:
+
+=over
+
+=item * Entire Tcl/Tk directory is copied into C<blib/lib>
+
+=item * Tcl.cfg file is created at the same dir where Tcl.pm is placed; this
+file contain some configuration and a code to initially load Tcl shared library.
+
+=back 
+
+=head3 Third method
+
+To link Tcl/Tk binaries, prepare their libraries and then instruct Makefile.PL
+to use these libraries in a link stage.
+(TODO provide better detailed description) 
+
 =head1 AUTHORS
 
 Malcolm Beattie, mbeattie@sable.ox.ac.uk, 23 Oct 1994.
-Vadim Konovalov, vkonovalov@peterstar.ru, 19 May 2003.
+Vadim Konovalov, vkon@cpan.org, 19 May 2003.
 Jeff Hobbs, jeff (a) activestate . com, 22 Mar 2004.
 Gisle Aas, gisle (a) activestate . com, 14 Apr 2004.
 
 =head1 COPYRIGHT
 
-This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 See http://www.perl.com/perl/misc/Artistic.html
 
@@ -317,6 +396,12 @@ use DynaLoader;
 use vars qw(@ISA);
 @ISA = qw(DynaLoader);
 
+# consideration for moveable configuration of tcl/tk
+# This is done before bootstraping, to make possible of searching of correct
+# shared libraries
+$Tcl::config::tcl_pm_path = [__FILE__=~/^(.*)Tcl\.pm$/i]->[0];
+do "$Tcl::config::tcl_pm_path/Tcl.cfg" if -f "$Tcl::config::tcl_pm_path/Tcl.cfg";
+
 Tcl->bootstrap($Tcl::VERSION);
 
 END {
